@@ -1,10 +1,9 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond.pool import Pool, PoolMeta
-from trytond.pyson import Eval, If
-
 from trytond.modules.analytic_account import AnalyticMixin
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
 
 
 class PurchaseLine(AnalyticMixin, metaclass=PoolMeta):
@@ -14,15 +13,12 @@ class PurchaseLine(AnalyticMixin, metaclass=PoolMeta):
     def __setup__(cls):
         super(PurchaseLine, cls).__setup__()
         cls.analytic_accounts.domain = [
-            ('company', '=', If(~Eval('_parent_purchase'),
-                    Eval('context', {}).get('company', -1),
-                    Eval('_parent_purchase', {}).get('company', -1))),
+            ('company', '=', Eval('company', -1)),
             ]
         cls.analytic_accounts.states = {
             'invisible': Eval('type') != 'line',
             'readonly': Eval('purchase_state') != 'draft',
             }
-        cls.analytic_accounts.depends.extend(['type', 'purchase_state'])
 
     def get_invoice_line(self):
         pool = Pool()
@@ -50,22 +46,17 @@ class AnalyticAccountEntry(metaclass=PoolMeta):
     def on_change_with_company(self, name=None):
         pool = Pool()
         PurchaseLine = pool.get('purchase.line')
-        company = super(AnalyticAccountEntry, self).on_change_with_company(
-            name)
+        company = super().on_change_with_company(name)
         if isinstance(self.origin, PurchaseLine) and self.origin.purchase:
-            company = self.origin.purchase.company.id
+            company = self.origin.purchase.company
         return company
 
     @classmethod
     def search_company(cls, name, clause):
-        operator = clause[1]
-        if operator.startswith('!') or operator.startswith('not '):
-            bool_op = 'AND'
-        else:
-            bool_op = 'OR'
         domain = super(AnalyticAccountEntry, cls).search_company(name, clause)
-        return [bool_op,
-            domain,
+        if domain:
+            domain = ['OR', domain]
+        domain.append(
             ('origin.purchase.' + clause[0],
-                *clause[1:3], 'purchase.line', *clause[3:]),
-            ]
+                *clause[1:3], 'purchase.line', *clause[3:]))
+        return domain
